@@ -24,9 +24,8 @@
 #
 
 
-.gams_description_max_length = 255
+.gams_description_max_length <- 255
 
-.is.integer0 <- function(x)
-{
+.is.integer0 <- function(x) {
   is.integer(x) && length(x) == 0L
 }
