@@ -47,6 +47,7 @@
 
 using namespace std::literals::string_literals;
 using namespace rtl::p3utils;
+using utils::ui8, utils::ui16, utils::ui32;
 
 #if defined(__IN_CPPMEX__)
 #include "../gdlib/statlib.h"
@@ -82,7 +83,7 @@ constexpr uint8_t signature_header = 0xFF;
 const std::string signature_gams = "*GAMS*"s;
 constexpr int verify_offset = 100;
 
-constexpr static char substChar {/*0x1A*/ std::char_traits<char>::eof()};
+constexpr static char substChar { std::numeric_limits<char>::is_signed ? std::char_traits<char>::eof() : 0x1A };
 
 union TDoubleVar
 {
@@ -117,7 +118,7 @@ void CompressTextFile( const std::string &fn, const std::string &fo, const std::
       NrRead = Fin.Read( Buffer.data(), (int) Buffer.size() );
       if( !NrRead ) break;
       Fout.Write( Buffer.data(), NrRead );
-   } while( NrRead >= static_cast<int>( Buffer.size() ) );
+   } while( NrRead >= static_cast<decltype(NrRead)>( Buffer.size() ) );
 }
 
 void UnCompressTextFile( const std::string &fn, const std::string &fo, const std::string &PassWord, int &ErrNr, std::string &ErrMsg )
@@ -588,19 +589,19 @@ bool TBufferedFileStream::FillBuffer()
    }
    else
    {
-      if( const uint16_t RLen = TXFileStream::Read( &CBufPtr->cxHeader, sizeof( TCompressHeader ) );
+      if( const auto RLen = ui16(TXFileStream::Read( &CBufPtr->cxHeader, sizeof( TCompressHeader ) ));
          RLen < sizeof( TCompressHeader ) )
          NrLoaded = 0;
       else
       {
-         const uint16_t WLen = ( CBufPtr->cxHeader.cxB1 << 8 ) + CBufPtr->cxHeader.cxB2;
+         const auto WLen = ui16( ( CBufPtr->cxHeader.cxB1 << 8 ) + CBufPtr->cxHeader.cxB2 );
          if( !CBufPtr->cxHeader.cxTyp ) NrLoaded = TXFileStream::Read( BufPtr.data(), WLen );
          else
          {
             TXFileStream::Read( &CBufPtr->cxData, WLen );
             unsigned long XLen = BufSize;// we need a var parameter
             uncompress( BufPtr.data(), &XLen, &CBufPtr->cxData, WLen );
-            NrLoaded = XLen;
+            NrLoaded = ui32(XLen);
          }
       }
    }
@@ -648,7 +649,7 @@ TBufferedFileStream::TBufferedFileStream( const std::string &FileName, uint16_t
       NrRead {},
       NrWritten {},
       BufSize { BufferSize },
-      CBufSize { static_cast<uint32_t>( std::round( static_cast<double>( BufferSize ) * 12.0 / 10.0 ) ) + 20 },
+      CBufSize {  utils::round<uint32_t>( static_cast<double>( BufferSize ) * 12.0 / 10.0 ) + 20 },
       BufPtr( BufferSize ),
       CBufPtr { static_cast<PCompressBuffer>( malloc( sizeof( TCompressHeader ) + CBufSize ) ) },
       FCompress {},
@@ -675,7 +676,7 @@ bool TBufferedFileStream::FlushBuffer()
    }
    else
    {
-      unsigned long Len = CBufSize - sizeof( TCompressHeader );
+      auto Len { static_cast<long unsigned int>(CBufSize - sizeof( TCompressHeader )) };
       compress( &CBufPtr->cxData, &Len, BufPtr.data(), NrWritten );
       if( Len < NrWritten )
       {
@@ -683,14 +684,14 @@ bool TBufferedFileStream::FlushBuffer()
          CBufPtr->cxHeader.cxB1 = static_cast<uint8_t>( Len >> 8 );
          CBufPtr->cxHeader.cxB2 = Len & 0xFF;
          Len += sizeof( TCompressHeader );
-         ActWritten = TXFileStream::Write( &CBufPtr->cxHeader.cxTyp, Len );
+         ActWritten = TXFileStream::Write( &CBufPtr->cxHeader.cxTyp, ui32(Len) );
          res = Len == ActWritten;
       }
       else
       {
          CBufPtr->cxHeader.cxTyp = 0;// indicates no compression
-         CBufPtr->cxHeader.cxB1 = NrWritten >> 8;
-         CBufPtr->cxHeader.cxB2 = NrWritten & 0xFF;
+         CBufPtr->cxHeader.cxB1 = ui8(NrWritten >> 8);
+         CBufPtr->cxHeader.cxB2 = ui8(NrWritten & 0xFF);
          TXFileStream::Write( &CBufPtr->cxHeader.cxTyp, sizeof( TCompressHeader ) );
          ActWritten = TXFileStream::Write( BufPtr.data(), NrWritten );
          res = NrWritten == ActWritten;
@@ -881,10 +882,10 @@ void TMiBufferedStream::WriteGmsInteger( int N )
    std::array<uint8_t, 5> W {};
    while( N )
    {
-      W[++C] = N & 255;
+      W[++C] = ui8(N & 255);
       N >>= 8;
    }
-   W[0] = B | C << 4;
+   W[0] = ui8(B | C << 4);
    Write( W.data(), C + 1 );
 }
 
@@ -904,7 +905,7 @@ static tgmsvalue mapval( double x )
    if( x < GMS_SV_UNDEF ) return xvreal;
    if( x >= GMS_SV_ACR ) return xvacr;
    x /= GMS_SV_UNDEF;
-   const int k = static_cast<int>( std::round( x ) );
+   const int k = utils::round<int>( x );
    if( std::abs( k - x ) > 1.0e-5 )
       return xvund;
    constexpr std::array<tgmsvalue, 5> kToRetMapping = {
@@ -933,10 +934,10 @@ void TMiBufferedStream::WriteGmsDouble( double D )
    if( B )
    {
       Write( &B, 1 );
-      if( gv == xvacr ) WriteGmsInteger( static_cast<int>( std::round( D / GMS_SV_ACR ) ) );
+      if( gv == xvacr ) WriteGmsInteger( utils::round<int>( D / GMS_SV_ACR ) );
       return;
    }
-   int C {};
+   uint8_t C {};
    TDoubleVar Z {};
    Z.V = D;
    if( NormalOrder )
@@ -949,7 +950,7 @@ void TMiBufferedStream::WriteGmsDouble( double D )
       }
       B = 128 | C;
       Write( &B, 1 );
-      assert( C >= 0 && C <= 7 );
+      assert( /*C >= 0 &&*/ C <= 7 );
       Write( &Z.VA[C], static_cast<uint32_t>( Z.VA.size() ) - C );
    }
    else
@@ -971,7 +972,7 @@ int TMiBufferedStream::ReadGmsInteger()
 {
    uint8_t B;
 #if !defined( NDEBUG )
-   auto numBytesRead { Read( &B, 1 ) };
+   const auto numBytesRead { Read( &B, 1 ) };
    assert( numBytesRead == 1 );
    // should not happen
    if( !numBytesRead )
