@@ -115,10 +115,19 @@ bool statusErrorNextJac( int &row, int &col );
 bool statusErrorDetail( int &cnt, std::string &msg );
 void statusErrorFree();
 
-// ...
+void statusSetRowCol(int rowmax, int colmax);
 
+bool statusFileOpen(gmsgen::tfileaction AAction, std::string &msg);
 void statusClose();
 
+void gcstat(const std::string &s);
+void gcstatPChar(const char *p);
+
+// ...
+// TODO: FIXME: Add missing functions!
+
+// you need to adjust gmoxxx\gmodoorg.pas
+
 void registerWriteCallback( gdlib::stattypes::tgwrite fptr, void *usermem );
 
 
@@ -138,11 +147,20 @@ void gstatReOpen();
 void gstatMemory(double M);
 void gstatErrorCnt( int N );
 
+// check if the log is "fresh enough", update if not
+void gstatFreshen();
+/*
+*check if the log is "fresh enough", update if not:
+called at regular time intervals, e.g. 200 ticks
+*/
+void gstatFreshenEx();
+
 void dumpfilename( const std::string &prfx, bool enabled, const std::string &what, const std::string &gs, gmsgen::tfileaction fa, int ioResOrNeg );
 
 bool gstatLogEnabled();
 
 // ...
+// TODO: Add missing functions!
 
 std::string GetRedirFileName();
 std::string GetRedirLogStr();
