@@ -27,9 +27,12 @@
 #include <cstring> // for strerror, size_t, strcmp, strcpy
 
 #include "sysutils_p3.h"
-#include "p3platform.h" // for OSFileType, tOSFileType
+#include "p3platform.h"// for OSFileType, tOSFileType
+
 #include "global/unit.h" // for UNIT_INIT_FINI
 
+#include "gdlib/utils.h" // for ui16
+
 #if defined( _WIN32 )
    #include <Windows.h>
    #include <io.h>
@@ -37,12 +40,15 @@
    #include <unistd.h> // for access, getcwd, unlink, F_OK
    #include <sys/stat.h> // for stat, S_ISDIR
    #include <sys/time.h> // for timeval, gettimeofday
+   #include <fnmatch.h>
 #endif
 
-using namespace global::delphitypes;
+
 using namespace rtl::p3platform;
 using namespace std::literals::string_literals;
 
+using utils::ui16;
+
 // ==============================================================================================================
 // Implementation
 // ==============================================================================================================
@@ -56,7 +62,7 @@ std::string ExtractShortPathName( const std::string &FileName )
 {
 #if defined( _WIN32 )
    std::array<char, 260> buf;
-   auto rc = GetShortPathNameA( FileName.c_str(), buf.data(), static_cast<DWORD>( sizeof( char ) * buf.size() ) );
+   const auto rc = GetShortPathNameA( FileName.c_str(), buf.data(), static_cast<DWORD>( sizeof( char ) * buf.size() ) );
    assert(rc);
    return buf.data();
 #else
@@ -92,14 +98,14 @@ bool FileExists( const std::string &FileName )
 #endif
 }
 
-static TTimeStamp DateTimeToTimeStamp( tDateTime DateTime )
+static TTimeStamp DateTimeToTimeStamp( global::delphitypes::tDateTime DateTime )
 {
    return {
-           static_cast<int>( round( std::abs( frac( DateTime ) ) * MSecsPerDay ) ),
+           static_cast<int>( round( std::abs( global::delphitypes::frac( DateTime ) ) * MSecsPerDay ) ),
            static_cast<int>( trunc( DateTime ) + DateDelta ) };
 }
 
-void DecodeTime( const tDateTime DateTime, uint16_t &Hour, uint16_t &Min, uint16_t &Sec, uint16_t &Msec )
+void DecodeTime( const global::delphitypes::tDateTime DateTime, uint16_t &Hour, uint16_t &Min, uint16_t &Sec, uint16_t &Msec )
 {
    uint16_t MinCount, MSecCount;
    const auto tmp = DateTimeToTimeStamp( DateTime );
@@ -111,14 +117,14 @@ void DecodeTime( const tDateTime DateTime, uint16_t &Hour, uint16_t &Min, uint16
 void DivMod( const int Dividend, const uint16_t Divisor, uint16_t &Result, uint16_t &Remainder )
 {
    const auto res = div( Dividend, Divisor );
-   Result = res.quot;
-   Remainder = res.rem;
+   Result = static_cast<uint16_t>(res.quot);
+   Remainder = static_cast<uint16_t>(res.rem);
 }
 
-/*static global::delphitypes::tDateTime EncodeDate( uint16_t Year, uint16_t Month, uint16_t Day )
+double EncodeDate( uint16_t Year, uint16_t Month, const uint16_t Day )
 {
-   if( Year == 1600 && Month < 3 )
-      return Day + ( Month == 1 ? 1 : 30 );
+   if( Year == 1600.0 && Month < 3.0 )
+      return Day + ( Month == 1 ? 1.0 : 30.0 );
    if( Month > 2 ) Month -= 3;
    else
    {
@@ -127,7 +133,7 @@ void DivMod( const int Dividend, const uint16_t Divisor, uint16_t &Result, uint1
    }
    const int Yr { Year - 1600 };
    return Yr / 100 * 146097 / 4 + Yr % 100 * 1461 / 4 + (153 * Month + 2) / 5 + Day + 59 - 109572 + 1;
-}*/
+}
 
 #if defined(_WIN32)
 static char * winErrMsg( int errNum, char *buf, int bufSiz )
@@ -135,7 +141,7 @@ static char * winErrMsg( int errNum, char *buf, int bufSiz )
    *buf = '\0';
    if( 0 == errNum )
       return buf;
-   BOOL brc = FormatMessageA(
+   const auto brc = FormatMessageA(
            FORMAT_MESSAGE_FROM_SYSTEM,
            nullptr,
            errNum,
@@ -166,7 +172,7 @@ std::string GetCurrentDir()
    std::array<char, 256> buf;
    buf.front() = '\0';
 #if defined(_WIN32)
-   const int rc = GetCurrentDirectoryA(static_cast<DWORD>(sizeof(char)*buf.size()),buf.data());
+   const auto rc = GetCurrentDirectoryA(static_cast<DWORD>(sizeof(char)*buf.size()),buf.data());
    if (!rc) {
       winErrMsg( GetLastError(), buf.data(), sizeof( buf ) );
       throw std::runtime_error( "GetCurrentDir failed"s + buf.data() );
@@ -207,8 +213,8 @@ std::string GetCurrentDir()
 
 bool DirectoryExists( const std::string &Directory )
 {
-#if defined(_WIN32)
-   int attribs = GetFileAttributesA(Directory.c_str());
+#if defined( _WIN32 )
+   const int attribs = GetFileAttributesA(Directory.c_str());
    return -1 != attribs && (attribs & FILE_ATTRIBUTE_DIRECTORY);
 #else
    struct stat statBuf;
@@ -236,8 +242,7 @@ bool DeleteFileFromDisk( const std::string &FileName )
 std::string QueryEnvironmentVariable( const std::string &Name )
 {
 #if defined( _WIN32 )
-   uint32_t len = GetEnvironmentVariableA( Name.c_str(), nullptr, 0 );
-   if( !len ) return ""s;
+   if( const uint32_t len = GetEnvironmentVariableA( Name.c_str(), nullptr, 0 ); !len ) return ""s;
    else
    {
       std::vector<char> buf( len );
@@ -286,7 +291,7 @@ std::string IncludeTrailingPathDelimiter( const std::string &S )
    return S + PathDelim;
 }
 
-const std::array<int, 12>
+const std::array<uint8_t, 12>
         daysPerMonthRegularYear = { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 },
         daysPerMonthLeapYear = { 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
 
@@ -315,6 +320,24 @@ int LastDelimiter( const std::string &Delimiters, const std::string &S )
    return -1;
 }
 
+bool CreateDir( const std::string &Dir )
+{
+#if defined(_WIN32)
+   return CreateDirectoryA( Dir.c_str(), nullptr );
+#else
+   return !mkdir( Dir.c_str(), 0777 );
+#endif
+}
+
+bool RemoveDir( const std::string &Dir )
+{
+#if defined(_WIN32)
+   return RemoveDirectoryA(Dir.c_str());
+#else
+   return !rmdir(Dir.c_str());
+#endif
+}
+
 std::string ChangeFileExt( const std::string &filename, const std::string &extension )
 {
    auto I {LastDelimiter( ExtStopper, filename )};
@@ -333,31 +356,147 @@ std::string ReplaceFileExt( const std::string &filename, const std::string &exte
    return ChangeFileExt( filename, extension );
 }
 
-int FindFirst( const std::string &Path, int Attr, TSearchRec &F )
+static int FindMatchingFile( TSearchRec &f )
 {
-   // ...
-   STUBWARN();
+#if defined( _WIN32 )
+   while( f.FindData->dwFileAttributes & f.ExcludeAttr )
+      if( !FindNextFile( f.FindHandle, reinterpret_cast<PWIN32_FIND_DATA>( &f.FindData ) ) )
+         return static_cast<int>( GetLastError() );
+   FILETIME lastWriteTime;
+   FILETIME localFileTime;
+   std::memcpy( &lastWriteTime, &( f.FindData->ftLastWriteTime ), sizeof( FILETIME ) );
+   FileTimeToLocalFileTime( &lastWriteTime, &localFileTime );
+   auto *wPtr = reinterpret_cast<WORD *>( &f.Time );
+   FileTimeToDosDateTime( &localFileTime, wPtr + 1, wPtr );
+   f.Size = static_cast<int>( f.FindData->nFileSizeLow );
+   f.Attr = static_cast<int>( f.FindData->dwFileAttributes );
+   f.Name = f.FindData->cFileName;
    return 0;
+#else
+   int result;
+   struct stat statbuf {
+   };
+   struct stat linkstatbuf {
+   };
+   result = -1;
+   auto *dp = f.FindHandle;
+   const dirent *dirEntry = readdir( dp );
+   while( dirEntry )
+   {
+      if( int rc = fnmatch( f.Pattern.c_str(), dirEntry->d_name, 0 ); 0 == rc )
+      {
+         // F.PathOnly must include trailing backslash
+         std::string fname = f.PathOnly + dirEntry->d_name;
+         rc = lstat( fname.c_str(), &statbuf );
+         if( !rc )
+         {
+            int attr = 0;
+            if( const mode_t mode = statbuf.st_mode; S_ISDIR( mode ) )
+               attr |= faDirectory;
+            else if( !S_ISREG( mode ) )
+            {
+               // directories should not be treated as system files
+               if( S_ISLNK( mode ) )
+               {
+                  attr |= faSymLink;
+                  if( 0 == lstat( fname.c_str(), &linkstatbuf ) && S_ISDIR( linkstatbuf.st_mode ) )
+                     attr |= faDirectory;
+               }
+               attr |= faSysFile;
+            }
+            if( dirEntry->d_name[0] == '.' && dirEntry->d_name[1] != '\0' )
+               if( !( dirEntry->d_name[1] == '.' && dirEntry->d_name[2] == '\0' ) )
+                  attr |= faHidden;
+            // if (euidaccess(fname, W_OK) != 0)
+            if( access( fname.c_str(), W_OK ) != 0 )
+               attr |= faReadOnly;
+            if( 0 == ( attr & f.ExcludeAttr ) )
+            {
+               f.Size = static_cast<int>( statbuf.st_size );
+               f.Attr = attr;
+               f.mode = statbuf.st_mode;
+               f.Name = dirEntry->d_name;
+               f.Time = static_cast<int>( statbuf.st_mtime );
+               result = 0;
+               break;
+            }// matching file found
+         }   // lstat returns OK
+      }      // matches desired pattern
+      dirEntry = readdir( dp );
+      result = -1;
+   }// readdir loop
+   return result;
+#endif// defined(_WIN32)
+}
+
+TSearchRec::~TSearchRec()
+{
+   FindClose(*this);
+#if defined(_WIN32)
+   delete FindData;
+#endif
+}
+
+int FindFirst(const std::string &Path, const int Attr, TSearchRec &F )
+{
+   F.ExcludeAttr = ~Attr & 30;
+   F.PathOnly = ExtractFilePath( Path );
+   if(F.PathOnly.empty())
+      F.PathOnly = IncludeTrailingPathDelimiter( GetCurrentDir() );
+   F.Pattern = ExtractFileName( Path );
+#if defined(_WIN32)
+   HANDLE fHandle;
+   F.FindData = new _WIN32_FIND_DATAA{}; // will be freed in F destructor
+   F.FindHandle = fHandle = FindFirstFileA(Path.c_str(), F.FindData );
+   if (INVALID_HANDLE_VALUE != fHandle) {
+      auto res = FindMatchingFile(F);
+      if (res != 0)
+         FindClose(F);
+      return res;
+   }
+   return static_cast<int>(GetLastError());
+#else
+   DIR *dp;
+   F.FindHandle = dp = opendir(F.PathOnly.c_str());
+   if( dp )
+   {
+      auto res = FindMatchingFile( F );
+      if( res )
+         FindClose( F );
+      return res;
+   }
+   return errno; // what should this be??
+#endif
 }
 
 int FindNext( TSearchRec &F )
 {
-   // ...
-   STUBWARN();
-   return 0;
+#if defined(_WIN32)
+   return FindNextFileA(F.FindHandle, F.FindData ) ? FindMatchingFile(F) : GetLastError();
+#else
+   return FindMatchingFile(F);
+#endif
 }
 
 void FindClose( TSearchRec &F )
 {
-   // ...
-   STUBWARN();
+#if defined(_WIN32)
+   if (INVALID_HANDLE_VALUE != F.FindHandle) {
+      ::FindClose(F.FindHandle);
+      F.FindHandle = INVALID_HANDLE_VALUE;
+   }
+#else
+   if (F.FindHandle) {
+      closedir(F.FindHandle);
+      F.FindHandle = nullptr;
+   }
+#endif
 }
 
-bool tryEncodeDate( uint16_t year, uint16_t month, uint16_t day, double &date )
+bool tryEncodeDate( const uint16_t year, const uint16_t month, uint16_t day, double &date )
 {
-   const std::array<int, 12> &daysPerMonth = isLeapYear( year ) ? daysPerMonthLeapYear : daysPerMonthRegularYear;
-
-   if( year >= 1 && year <= 9999 && month >= 1 && month <= 12 && day >= 1 && day <= daysPerMonth[month - 1] )
+   if( const std::array<uint8_t, 12> &daysPerMonth = isLeapYear( year ) ? daysPerMonthLeapYear : daysPerMonthRegularYear;
+      year >= 1 && year <= 9999 && month >= 1 && month <= 12 && day >= 1 && day <= daysPerMonth[month - 1] )
    {
       const int stop = month - 1;
       int i { 1 };
@@ -375,7 +514,7 @@ bool tryEncodeDate( uint16_t year, uint16_t month, uint16_t day, double &date )
    return false;
 }
 
-static bool tryEncodeTime( uint16_t hour, uint16_t minute, uint16_t sec, uint16_t msec, double &curt )
+static bool tryEncodeTime( const uint16_t hour, const uint16_t minute, const uint16_t sec, const uint16_t msec, double &curt )
 {
    if( hour < HoursPerDay && minute < MinsPerHour && /*sec < SecsPerDay &&*/ msec < MSecsPerSec )
    {
@@ -401,18 +540,18 @@ double Now()
    if(gettimeofday(&tv, nullptr) || !localtime_r(&tv.tv_sec, &lt))
       return 0.0;
    double dnow, tnow;
-   const bool rc1 = tryEncodeDate( lt.tm_year + 1900, lt.tm_mon + 1, lt.tm_mday, dnow );
-   const bool rc2 = tryEncodeTime (lt.tm_hour, lt.tm_min, lt.tm_sec, tv.tv_usec/1000, tnow);
+   const bool rc1 = tryEncodeDate( ui16(lt.tm_year + 1900), ui16(lt.tm_mon + 1), ui16(lt.tm_mday), dnow );
+   const bool rc2 = tryEncodeTime (ui16(lt.tm_hour), ui16(lt.tm_min), ui16(lt.tm_sec), ui16(tv.tv_usec/1000), tnow);
    return rc1 && rc2 ? dnow + tnow : 0.0;
 #endif
 }
 
-/*static double EncodeDateTime( uint16_t Year, uint16_t Month, uint16_t Day, uint16_t Hour, uint16_t Minute, uint16_t Second, uint16_t Millisecond )
+double EncodeDateTime( const uint16_t Year, const uint16_t Month, const uint16_t Day, const uint16_t Hour, const uint16_t Minute, const uint16_t Second, const uint16_t Millisecond )
 {
    const double integerPart = EncodeDate( Year, Month, Day );
    const double fractionalHoursInDay = static_cast<double>( Millisecond ) / 36e5 + static_cast<double>( Second ) / 3600.0 + static_cast<double>( Minute ) / 60.0 + Hour;
    return integerPart + fractionalHoursInDay / 24.0;
-}*/
+}
 
 static bool DecodeDateFully(const double DateTime, uint16_t &Year, uint16_t &Month, uint16_t &Day, uint16_t &DOW)
 {
@@ -426,7 +565,7 @@ static bool DecodeDateFully(const double DateTime, uint16_t &Year, uint16_t &Mon
       Year = Month = Day = DOW = 0;
       return false;
    }
-   DOW = T % 7 + 1;
+   DOW = ui16(T % 7 + 1);
    T--;
    uint16_t Y = 1;
    while( T >= D400 )
@@ -441,9 +580,9 @@ static bool DecodeDateFully(const double DateTime, uint16_t &Year, uint16_t &Mon
       I--;
       D += D100;
    }
-   Y += I * 100;
+   Y += ui16(I * 100);
    DivMod( D, D4, I, D );
-   Y += I * 4;
+   Y += ui16(I * 4);
    DivMod( D, D1, I, D );
    if( I == 4 )
    {
@@ -466,7 +605,7 @@ static bool DecodeDateFully(const double DateTime, uint16_t &Year, uint16_t &Mon
    return res;
 }
 
-void DecodeDate( const tDateTime DateTime, uint16_t &Year, uint16_t &Month, uint16_t &Day )
+void DecodeDate( const global::delphitypes::tDateTime DateTime, uint16_t &Year, uint16_t &Month, uint16_t &Day )
 {
    uint16_t Dummy {};
    DecodeDateFully(DateTime, Year, Month, Day, Dummy);
@@ -514,12 +653,12 @@ std::string IntToStr( int64_t n )
    else n *= -1;
    int64_t w {255};
    do {
-      res[w-- - 1] = '0' - (char)(n % 10);
+      res[w-- - 1] = '0' - static_cast<char>( n % 10 );
       n /= 10;
    } while(n);
    while(w < 255)
       res[w2++] = res[w++];
-   return {res.data(), (size_t)w2};
+   return {res.data(), static_cast<size_t>( w2 ) };
 }
 
 // Buffer res must be at least 256 bytes wide!
@@ -540,15 +679,68 @@ void IntToStr( int64_t n, char *res, size_t &len )
       n *= -1;
    int64_t w { 255 };
    do {
-      res[w-- - 1] = '0' - (char) ( n % 10 );
+      res[w-- - 1] = '0' - static_cast<char>( n % 10 );
       n /= 10;
    } while( n );
    while( w < 255 )
       res[w2++] = res[w++];
-   len = (size_t) w2;
+   len = static_cast<size_t>( w2 );
    res[len] = '\0';
 }
 
+double EncodeTime( const uint16_t hour, const uint16_t min, const uint16_t sec, const uint16_t msec) {
+   return ( hour * 3600000.0 + min * 60000 + sec * 1000 + msec ) / ( 24 * 3600000 );
+}
+
+double FileDateToDateTime( int fd )
+{
+#if defined(_WIN32)
+   LongRec rec;
+   static_assert( sizeof( int ) == sizeof( LongRec ) );
+   std::memcpy( &rec, &fd, sizeof( int ) );
+   return EncodeDate( ( rec.parts.hi >> 9 ) + 1980, ( rec.parts.hi >> 5 ) & 15, rec.parts.hi & 31 ) +
+      EncodeTime(rec.parts.lo >> 11, (rec.parts.lo >> 5) & 63, (rec.parts.lo & 31) << 1, 0);
+#else
+   tm ut {};
+   time_t tim;
+   tim = fd;
+   localtime_r( &tim, &ut );
+   return EncodeDate( ui16(ut.tm_year + 1900), ui16(ut.tm_mon + 1), ui16(ut.tm_mday) ) +
+      EncodeTime( ui16(ut.tm_hour), ui16(ut.tm_min), ui16(ut.tm_sec), 0 );
+#endif
+}
+
+int DateTimeToFileDate( double dt )
+{
+   uint16_t year, month, day;
+   DecodeDate( dt, year, month, day );
+   if( year < 1980 || year > 2107 ) return 0;// out of range
+   uint16_t hour, min, sec, msec;
+   DecodeTime( dt, hour, min, sec, msec );
+#if defined(_WIN32)
+   LongRec lr {
+      static_cast<uint16_t>( ( sec >> 1 ) | ( min << 5 ) | ( hour << 11 ) ),
+      static_cast<uint16_t>(day | ( month << 5 ) | ( (year - 1980) << 9 ))
+   };
+   static_assert( sizeof( LongRec ) == sizeof( int ) );
+   int res;
+   std::memcpy( &res, &lr, sizeof( int ) );
+   return res;
+#else
+   tm tm;
+   tm.tm_sec = sec;
+   tm.tm_min = min;
+   tm.tm_hour = hour;
+   tm.tm_mday = day;
+   tm.tm_mon = month - 1;
+   tm.tm_year = year - 1900;
+   tm.tm_wday = 0; /* ignored anyway */
+   tm.tm_yday = 0; /* ignored anyway */
+   tm.tm_isdst = -1;
+   return static_cast<int>(mktime( &tm ));
+#endif
+}
+
 static void initialization()
 {
    switch( OSFileType() )
